==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Pas de résultats</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Désinstaller %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Supprimer du bureau</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Supprimer du dock</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Désinstaller</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Ouvrir par proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Désactivez la mise à l&apos;échelle de l&apos;affichage</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Envoyer sur le bureau</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Épingler au lanceur</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Supprimer du démarrage</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Ajouter au démarrage</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Toutes les application</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphisme</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Autres</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Désinstaller %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Toutes les dépendances seront supprimées</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur </translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mettre en veille </translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédent </translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur </translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mettre en veille </translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédent </translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur </translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres </translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Toutes catégories</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Désinstaller %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Pas de résultats</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphisme</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Êtes-vous sûr de vouloir désinstaller %1 ? </translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Supprimer du bureau</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Supprimer du dock</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Désinstaller</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Désactivez la mise à l&apos;échelle de l&apos;affichage</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Envoyer sur le bureau</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Épingler au lanceur</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Supprimer du démarrage</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Ajouter au démarrage</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Toutes les application</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Graphisme</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Jeux</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Bureautique</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Autres</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur </translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mettre en veille </translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédent </translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur </translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mettre en veille </translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Précédent </translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur </translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Téléchargements</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres </translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Alimentation</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Toutes catégories</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Êtes-vous sûr de vouloir désinstaller %1 ? </translation>
    </message>
</context>
</TS>
